Rasters for Django
==================

Django-raster provides raster data integration for Django projects
with a PostGIS database backend.

`See the docs for more information`__

__ http://django-raster.readthedocs.org/en/latest/
